@@ -4,7 +4,7 @@ from django.db import models
 import caching.base
 
 class Orthography(models.Model):
-    word = models.CharField(max_length = 250,unique=True)
+    spelling = models.CharField(max_length = 250,unique=True)
 
     def __unicode__(self):
         return self.word
